@@ -329,12 +329,12 @@ public:
   /**
   * Specify the first field name to be used in this filter.
   */
-  void SetField1(char* fieldName);
+  void SetField1(const char* fieldName);
 
   /**
   * Specify the second field name to be used in the filter.
   */
-  void SetField2(char* fieldName);
+  void SetField2(const char* fieldName);
 
   /**
   * This structure lists the vertices to use for the marching tetrahedra,
@@ -387,11 +387,11 @@ public:
 
 protected:
   vtkFiberSurface();
-  virtual int FillInputPortInformation(int port, vtkInformation* info) override;
-  virtual int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
+  int FillInputPortInformation(int port, vtkInformation* info) override;
+  int RequestData(vtkInformation*, vtkInformationVector**, vtkInformationVector*) override;
 
   // name of the input array names.
-  char* Fields[2];
+  const char* Fields[2];
 
 private:
   vtkFiberSurface(const vtkFiberSurface&) = delete;
