@@ -18,7 +18,8 @@
 /* Use the libproj library configured for VTK.  */
 #define VTK_USE_SYSTEM_LIBPROJ
 #ifdef VTK_USE_SYSTEM_LIBPROJ
-# include <projects.h>
+# include <proj.h>
+# define ACCEPT_USE_OF_DEPRECATED_PROJ_API_H 1
 # include <proj_api.h>
 # include <geodesic.h>
 #else
