@@ -451,77 +451,53 @@ public class vtkAlgorithm extends vtkObject
   public void SetDefaultExecutivePrototype(vtkExecutive id0)
     { SetDefaultExecutivePrototype_84(id0); }
 
-  private native int SetUpdateExtentToWholeExtent_85(int id0);
-  public int SetUpdateExtentToWholeExtent(int id0)
-    { return SetUpdateExtentToWholeExtent_85(id0); }
-
-  private native int SetUpdateExtentToWholeExtent_86();
-  public int SetUpdateExtentToWholeExtent()
-    { return SetUpdateExtentToWholeExtent_86(); }
-
-  private native void SetUpdateExtent_87(int id0,int id1,int id2,int id3);
-  public void SetUpdateExtent(int id0,int id1,int id2,int id3)
-    { SetUpdateExtent_87(id0,id1,id2,id3); }
-
-  private native void SetUpdateExtent_88(int id0,int id1,int id2);
-  public void SetUpdateExtent(int id0,int id1,int id2)
-    { SetUpdateExtent_88(id0,id1,id2); }
-
-  private native void SetUpdateExtent_89(int id0,int id1[]);
-  public void SetUpdateExtent(int id0,int id1[])
-    { SetUpdateExtent_89(id0,id1); }
-
-  private native void SetUpdateExtent_90(int id0[]);
-  public void SetUpdateExtent(int id0[])
-    { SetUpdateExtent_90(id0); }
-
-  private native int[]  GetUpdateExtent_91();
+  private native int[]  GetUpdateExtent_85();
   public int[]  GetUpdateExtent()
-    { return GetUpdateExtent_91(); }
+    { return GetUpdateExtent_85(); }
 
-  private native int[]  GetUpdateExtent_92(int id0);
+  private native int[]  GetUpdateExtent_86(int id0);
   public int[]  GetUpdateExtent(int id0)
-    { return GetUpdateExtent_92(id0); }
+    { return GetUpdateExtent_86(id0); }
 
-  private native void GetUpdateExtent_93(int id0[]);
+  private native void GetUpdateExtent_87(int id0[]);
   public void GetUpdateExtent(int id0[])
-    { GetUpdateExtent_93(id0); }
+    { GetUpdateExtent_87(id0); }
 
-  private native void GetUpdateExtent_94(int id0,int id1[]);
+  private native void GetUpdateExtent_88(int id0,int id1[]);
   public void GetUpdateExtent(int id0,int id1[])
-    { GetUpdateExtent_94(id0,id1); }
+    { GetUpdateExtent_88(id0,id1); }
 
-  private native int GetUpdatePiece_95();
+  private native int GetUpdatePiece_89();
   public int GetUpdatePiece()
-    { return GetUpdatePiece_95(); }
+    { return GetUpdatePiece_89(); }
 
-  private native int GetUpdatePiece_96(int id0);
+  private native int GetUpdatePiece_90(int id0);
   public int GetUpdatePiece(int id0)
-    { return GetUpdatePiece_96(id0); }
+    { return GetUpdatePiece_90(id0); }
 
-  private native int GetUpdateNumberOfPieces_97();
+  private native int GetUpdateNumberOfPieces_91();
   public int GetUpdateNumberOfPieces()
-    { return GetUpdateNumberOfPieces_97(); }
+    { return GetUpdateNumberOfPieces_91(); }
 
-  private native int GetUpdateNumberOfPieces_98(int id0);
+  private native int GetUpdateNumberOfPieces_92(int id0);
   public int GetUpdateNumberOfPieces(int id0)
-    { return GetUpdateNumberOfPieces_98(id0); }
+    { return GetUpdateNumberOfPieces_92(id0); }
 
-  private native int GetUpdateGhostLevel_99();
+  private native int GetUpdateGhostLevel_93();
   public int GetUpdateGhostLevel()
-    { return GetUpdateGhostLevel_99(); }
+    { return GetUpdateGhostLevel_93(); }
 
-  private native int GetUpdateGhostLevel_100(int id0);
+  private native int GetUpdateGhostLevel_94(int id0);
   public int GetUpdateGhostLevel(int id0)
-    { return GetUpdateGhostLevel_100(id0); }
+    { return GetUpdateGhostLevel_94(id0); }
 
-  private native void SetProgressObserver_101(vtkProgressObserver id0);
+  private native void SetProgressObserver_95(vtkProgressObserver id0);
   public void SetProgressObserver(vtkProgressObserver id0)
-    { SetProgressObserver_101(id0); }
+    { SetProgressObserver_95(id0); }
 
-  private native long GetProgressObserver_102();
+  private native long GetProgressObserver_96();
   public vtkProgressObserver GetProgressObserver() {
-    long temp = GetProgressObserver_102();
+    long temp = GetProgressObserver_96();
 
     if (temp == 0) return null;
     return (vtkProgressObserver)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
