@@ -35,29 +35,41 @@ public class vtkExporter extends vtkObject
     return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetInput_6(vtkRenderWindow id0);
-  public void SetInput(vtkRenderWindow id0)
-    { SetInput_6(id0); }
+  private native void SetActiveRenderer_6(vtkRenderer id0);
+  public void SetActiveRenderer(vtkRenderer id0)
+    { SetActiveRenderer_6(id0); }
 
-  private native long GetInput_7();
+  private native long GetActiveRenderer_7();
+  public vtkRenderer GetActiveRenderer() {
+    long temp = GetActiveRenderer_7();
+
+    if (temp == 0) return null;
+    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
+  private native void SetInput_8(vtkRenderWindow id0);
+  public void SetInput(vtkRenderWindow id0)
+    { SetInput_8(id0); }
+
+  private native long GetInput_9();
   public vtkRenderWindow GetInput() {
-    long temp = GetInput_7();
+    long temp = GetInput_9();
 
     if (temp == 0) return null;
     return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetStartWrite_8(Object id0, String id1);
+  private native void SetStartWrite_10(Object id0, String id1);
   public void SetStartWrite(Object id0, String id1)
-    { SetStartWrite_8(id0,id1); }
+    { SetStartWrite_10(id0,id1); }
 
-  private native void SetEndWrite_9(Object id0, String id1);
+  private native void SetEndWrite_11(Object id0, String id1);
   public void SetEndWrite(Object id0, String id1)
-    { SetEndWrite_9(id0,id1); }
+    { SetEndWrite_11(id0,id1); }
 
-  private native int GetMTime_10();
+  private native int GetMTime_12();
   public int GetMTime()
-    { return GetMTime_10(); }
+    { return GetMTime_12(); }
 
   public vtkExporter() { super(); }
 
