@@ -19,33 +19,29 @@ public class vtkHomogeneousTransform extends vtkAbstractTransform
   public void TransformPoints(vtkPoints id0,vtkPoints id1)
     { TransformPoints_2(id0,id1); }
 
-  private native void TransformPointsNormalsVectors_3(vtkPoints id0,vtkPoints id1,vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkDataArray id5);
-  public void TransformPointsNormalsVectors(vtkPoints id0,vtkPoints id1,vtkDataArray id2,vtkDataArray id3,vtkDataArray id4,vtkDataArray id5)
-    { TransformPointsNormalsVectors_3(id0,id1,id2,id3,id4,id5); }
-
-  private native void GetMatrix_4(vtkMatrix4x4 id0);
+  private native void GetMatrix_3(vtkMatrix4x4 id0);
   public void GetMatrix(vtkMatrix4x4 id0)
-    { GetMatrix_4(id0); }
+    { GetMatrix_3(id0); }
 
-  private native long GetMatrix_5();
+  private native long GetMatrix_4();
   public vtkMatrix4x4 GetMatrix() {
-    long temp = GetMatrix_5();
+    long temp = GetMatrix_4();
 
     if (temp == 0) return null;
     return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetHomogeneousInverse_6();
+  private native long GetHomogeneousInverse_5();
   public vtkHomogeneousTransform GetHomogeneousInverse() {
-    long temp = GetHomogeneousInverse_6();
+    long temp = GetHomogeneousInverse_5();
 
     if (temp == 0) return null;
     return (vtkHomogeneousTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void InternalTransformPoint_7(double id0[],double id1[]);
+  private native void InternalTransformPoint_6(double id0[],double id1[]);
   public void InternalTransformPoint(double id0[],double id1[])
-    { InternalTransformPoint_7(id0,id1); }
+    { InternalTransformPoint_6(id0,id1); }
 
   public vtkHomogeneousTransform() { super(); }
 
