@@ -111,17 +111,9 @@ public class vtkMatrix3x3 extends vtkObject
   public double GetElement(int id0,int id1)
     { return GetElement_25(id0,id1); }
 
-  private native double Determinant_26(vtkMatrix3x3 id0);
-  public double Determinant(vtkMatrix3x3 id0)
-    { return Determinant_26(id0); }
-
-  private native void PointMultiply_27(double id0[],double id1[],double id2[]);
-  public void PointMultiply(double id0[],double id1[],double id2[])
-    { PointMultiply_27(id0,id1,id2); }
-
-  private native boolean IsIdentity_28();
+  private native boolean IsIdentity_26();
   public boolean IsIdentity()
-    { return IsIdentity_28(); }
+    { return IsIdentity_26(); }
 
   public vtkMatrix3x3() { super(); }
 
