@@ -179,6 +179,10 @@ public class vtkPoints extends vtkObject
   public int GetMTime()
     { return GetMTime_41(); }
 
+  private native void Modified_42();
+  public void Modified()
+    { Modified_42(); }
+
   public vtkPoints() { super(); }
 
   public vtkPoints(long id) { super(id); }
