@@ -43,6 +43,22 @@ public class vtkTransformFilter extends vtkPointSetAlgorithm
   public int GetOutputPointsPrecision()
     { return GetOutputPointsPrecision_7(); }
 
+  private native void SetTransformAllInputVectors_8(boolean id0);
+  public void SetTransformAllInputVectors(boolean id0)
+    { SetTransformAllInputVectors_8(id0); }
+
+  private native boolean GetTransformAllInputVectors_9();
+  public boolean GetTransformAllInputVectors()
+    { return GetTransformAllInputVectors_9(); }
+
+  private native void TransformAllInputVectorsOn_10();
+  public void TransformAllInputVectorsOn()
+    { TransformAllInputVectorsOn_10(); }
+
+  private native void TransformAllInputVectorsOff_11();
+  public void TransformAllInputVectorsOff()
+    { TransformAllInputVectorsOff_11(); }
+
   public vtkTransformFilter() { super(); }
 
   public vtkTransformFilter(long id) { super(id); }
